@@ -39,7 +39,7 @@ use Capture::Tiny qw(capture);
 
 Readonly our $DEFAULT_MAXRUNS => 10;
 
-our $VERSION = "0.300.1";
+our $VERSION = "0.300.2";
 
 __PACKAGE__->mk_accessors( qw( basename basedir basepath options
                                source output tmpdir format timeout stderr
@@ -79,10 +79,11 @@ our %FORMATTERS  = (
     pdf        => [ 'xelatex' ],
     'pdf(pdflatex)' => [ 'pdflatex' ],
     'pdf(xelatex)'  => [ 'xelatex' ],
-    'ps(xelatex)'  => [ 'xelatex', 'pdf2ps' ],
     'pdf(dvi)'      => [ 'latex', 'dvipdfm' ],
     'pdf(ps)'       => [ 'latex', 'dvips', 'ps2pdf' ],
     'ps(pdf)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(pdflatex)'       => [ 'pdflatex', 'pdf2ps' ],
+    'ps(xelatex)'       => [ 'xelatex', 'pdf2ps' ],
 );
 
 
@@ -133,7 +134,9 @@ sub new {
     # specified it is taken from that, or the default is take.
 
     my $output = $options->{output};
-    my $format = lc($options->{format});
+    my $format;
+    $format = lc($options->{format})
+        if $options->{format};
 
     if ($output and (!ref $output)) {
         my ($volume, $dir, $file) = File::Spec->splitpath($output);
